SystemOrganization addCategory: #ExperimentalBit!

TestCase subclass: #ExperimentalBitTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExperimentalBit'!

!ExperimentalBitTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 12/21/2011 12:09'!
testBasicSetAndGet
	| object object2 |
	object := Object new.
	object2 := Object.	
	object experimentalBit: false.
	object2 experimentalBit: false.
			
	self deny: object isExperimentalBitOn.
	self deny: object2 isExperimentalBitOn.

	object experimentalBit: true.
	self assert: object isExperimentalBitOn.
	self deny: object2 isExperimentalBitOn.
	
	object experimentalBit: false.
	self deny: object isExperimentalBitOn.
	self deny: object2 isExperimentalBitOn.
	
	object2 experimentalBit: true.
	self deny: object isExperimentalBitOn.
	self assert: object2 isExperimentalBitOn.! !

!ExperimentalBitTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 12/21/2011 12:05'!
testClearAllExperimentalBit
	| object object2 |
	object := Object new.
	object2 := Object.	

	object experimentalBit: true.
	object2 experimentalBit: true.
	
	ExperimentalBitHandler turnOffExperimentalBitOfAllObjects.
	
	self deny: object isExperimentalBitOn.
	self deny: object2 isExperimentalBitOn.! !

!ExperimentalBitTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 12/22/2011 12:32'!
testMarkSmallInteger
	
	self should: [42 experimentalBit: true] raise: Error.
	self should: [0 experimentalBit: true] raise: Error.
	self should: [-42 experimentalBit: true] raise: Error.
	self should: [SmallInteger minVal  experimentalBit: true] raise: Error.
	self should: [SmallInteger maxVal experimentalBit: true] raise: Error.
	self shouldnt: [(SmallInteger maxVal + 1)  experimentalBit: true] raise: Error.
	
	! !

!ExperimentalBitTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 12/22/2011 12:29'!
testMarkWithIncorrectParameter
	
	self should: ['anObject' experimentalBit: 42 ] raise: Error.
	self should: ['anObject' experimentalBit: 'xxx' ] raise: Error.
	self should: ['anObject' experimentalBit: Object new ] raise: Error.
	self shouldnt: ['anObject' experimentalBit: true ] raise: Error.
	self shouldnt: ['anObject' experimentalBit: false ] raise: Error.
! !

Object subclass: #ExperimentalBitHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExperimentalBit'!

!ExperimentalBitHandler commentStamp: 'MarianoMartinezPeck 12/22/2011 19:20' prior: 0!
ExperimentalBitHandler is a small facade for setting and getting the value of a bit in the Object Header. It requires a special VM which supports the primitives to set and get the value of such bit. You can get a already compiled MacOSX VM from: https://gforge.inria.fr/frs/download.php/30042/CogMTVM-ExperimentalBit.zip.
 
To know which version of the VM you have to use to compile, check the dependencies in ConfigurationOfExperimentalBit and also the 'description' of it. For example, if version 1.0 it depends on 'CogVM' version '3.7'. In the description of version 1.0 you can also read that the used Git version of the platform code was 4a65655f0e419248d09a2502ea13b6e787992691 from the blessed repo.

Basically, there are 3 operations: set the bit to a specific, get the value of the bit and turn off the bit of all objects. Examples:

'aString' experimentalBit: true.
'astring ' experimentalBit.
Date today experimentalBit: false.
Date today experimentalBit. 
ExperimentalBitHandler turnOffExperimentalBitOfAllObjects.

For more details see ExperimentalBitTest.
    !

!ExperimentalBitHandler class methodsFor: 'as yet unclassified' stamp: 'MarianoMartinezPeck 12/21/2011 12:02'!
primitiveTurnOffExperimentalBitOfAllObjects

	<primitive: 152>
	self primitiveFailed! !

!ExperimentalBitHandler class methodsFor: 'as yet unclassified' stamp: 'MarianoMartinezPeck 12/21/2011 12:04'!
turnOffExperimentalBitOfAllObjects

	self primitiveTurnOffExperimentalBitOfAllObjects ! !

!Object methodsFor: '*ExperimentalBit' stamp: 'MarianoMartinezPeck 12/21/2011 11:22'!
experimentalBit
	^ self primitiveGetExperimentalBit ! !

!Object methodsFor: '*ExperimentalBit' stamp: 'MarianoMartinezPeck 12/21/2011 11:22'!
experimentalBit: aBoolean
	self primitiveSetExperimentalBitTo: aBoolean! !

!Object methodsFor: '*ExperimentalBit' stamp: 'MarianoMartinezPeck 12/21/2011 11:25'!
isExperimentalBitOn
	^ self experimentalBit! !

!Object methodsFor: '*ExperimentalBit' stamp: 'MarianoMartinezPeck 12/21/2011 11:14'!
primitiveGetExperimentalBit

	<primitive: 150>
	self primitiveFailed! !

!Object methodsFor: '*ExperimentalBit' stamp: 'MarianoMartinezPeck 12/21/2011 11:16'!
primitiveSetExperimentalBitTo: aBoolean

	<primitive: 151>
	self primitiveFailed! !
